@@ -274,7 +274,7 @@ bool CNetworkConnection::IsComputerNameLocal(const wxString& strMachine) {
 
 
 int CNetworkConnection::SetComputer(
-    const wxChar* szComputer, const int iPort, const wxChar* szPassword,
+    const wxString& szComputer, const int iPort, const wxString& szPassword,
     const bool bUseDefaultPassword
 ) {
     m_strNewComputerName.Empty();
@@ -582,7 +582,6 @@ int CMainDocument::OnPoll() {
         }
         
         if (IsComputerNameLocal(hostName)) {
-            pFrame->UpdateStatusText(_("Starting client"));
             if (m_pClientManager->StartupBOINCCore()) {
                 Connect(wxT("localhost"), portNum, password, TRUE, TRUE);
             } else {
@@ -590,11 +589,8 @@ int CMainDocument::OnPoll() {
                 pFrame->ShowDaemonStartFailedAlert();
             }
         } else {
-            pFrame->UpdateStatusText(_("Connecting to client"));
             Connect(hostName, portNum, password, TRUE, password.IsEmpty());
         }
-
-        pFrame->UpdateStatusText(wxEmptyString);
     }
 
     // Check connection state, connect if needed.
@@ -646,7 +642,7 @@ int CMainDocument::ResetState() {
 }
 
 
-int CMainDocument::Connect(const wxChar* szComputer, int iPort, const wxChar* szComputerPassword, const bool bDisconnect, const bool bUseDefaultPassword) {
+int CMainDocument::Connect(const wxString& szComputer, int iPort, const wxString& szComputerPassword, const bool bDisconnect, const bool bUseDefaultPassword) {
     if (IsComputerNameLocal(szComputer)) {
         // Restart client if not already running
         m_pClientManager->AutoRestart();
@@ -692,7 +688,7 @@ int CMainDocument::GetConnectingComputerName(wxString& strMachine) {
 }
 
 
-bool CMainDocument::IsComputerNameLocal(const wxString strMachine) {
+bool CMainDocument::IsComputerNameLocal(const wxString& strMachine) {
     return m_pNetworkConnection->IsComputerNameLocal(strMachine);
 }
 
@@ -1199,13 +1195,9 @@ int CMainDocument::ForceCacheUpdate(bool immediate) {
         return m_iGet_state_rpc_result;
     }
     
-    CBOINCBaseFrame* pFrame = wxGetApp().GetFrame();
     int     retval = 0;
 
     if (IsConnected()) {
-        wxASSERT(wxDynamicCast(pFrame, CBOINCBaseFrame));
-        pFrame->UpdateStatusText(_("Retrieving system state; please wait..."));
-
         m_dtCachedStateTimestamp = wxDateTime::Now();
         m_iGet_state_rpc_result = rpc.get_state(state);
         if (m_iGet_state_rpc_result) {
@@ -1214,7 +1206,6 @@ int CMainDocument::ForceCacheUpdate(bool immediate) {
             m_pNetworkConnection->SetStateDisconnected();
         }
 
-        pFrame->UpdateStatusText(wxEmptyString);
     } else {
         retval = -1;
     }
